pub type TimeoutCertificate<TYPES> = SimpleCertificate<TYPES, TimeoutData, SuccessThreshold>;Expand description
Type alias for a Timeout certificate over a view number
Aliased Type
pub struct TimeoutCertificate<TYPES> {
pub data: TimeoutData,
vote_commitment: Commitment<TimeoutData>,
pub view_number: ViewNumber,
pub signatures: Option<<<TYPES as NodeType>::SignatureKey as SignatureKey>::QcType>,
pub _pd: PhantomData<(TYPES, SuccessThreshold)>,
}Fields
data: TimeoutDataThe data this certificate is for. I.e the thing that was voted on to create this Certificate
vote_commitment: Commitment<TimeoutData>commitment of all the votes this cert should be signed over
view_number: ViewNumberWhich view this QC relates to
signatures: Option<<<TYPES as NodeType>::SignatureKey as SignatureKey>::QcType>assembled signature for certificate aggregation
_pd: PhantomData<(TYPES, SuccessThreshold)>phantom data for THRESHOLD and TYPES
Implementations
Sourceimpl<TYPES: NodeType> TimeoutCertificate<TYPES>
impl<TYPES: NodeType> TimeoutCertificate<TYPES>
Sourcepub fn to_tc2(self) -> TimeoutCertificate2<TYPES>
pub fn to_tc2(self) -> TimeoutCertificate2<TYPES>
Convert a DaCertificate into a DaCertificate2